@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2007 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -110,7 +110,8 @@ char *process::receive(void)
 
 retry:
 	buf[0] = 0;
-	fgets(buf, sizeof(buf), fifo);
+	if(fgets(buf, sizeof(buf), fifo) == NULL)
+		buf[0] = 0;
 	cp = String::strip(buf, " \t\r\n");
 	if(*cp == '/') {
 		if(strstr(cp, ".."))
