@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2007 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -85,9 +85,9 @@ public:
 };
 
 #if defined(DEBUG) || defined(OLD_STDCPP) || defined(NEW_STDCPP)
-#define	debug(l, a...)	process::errlog((errlevel_t)(INFO + l), ## a)
+#define	debug(l, args...)	process::errlog((errlevel_t)(INFO + l), ## args)
 #else
-#define	debug(l, a...)
+#define	debug(l, args...)
 #endif
 
 END_NAMESPACE
