@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2007 David Sugar, Tycho Softworks.
+// Copyright (C) 2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@ modules::sipwitch()
 	realm = (char *)"GNU Telephony";
 	proxy = NULL;
 	freelist = NULL;
-	memset(index, sizeof(index), 0);
+	memset(index, 0, sizeof(index));
 	allocated = active = 0;
 	expires = 120;
 }
@@ -151,8 +151,6 @@ void forward::reload(service *cfg)
 {
 	assert(cfg != NULL);
 
-	char *cp;
-	unsigned len;
 	char buffer[160];
 	bool refering = false;
 	bool enable = false;
