@@ -61,7 +61,7 @@ public:
 		void incUse(void);
 		void decUse(void);
 		bool expire(Socket::address& addr);
-		bool refresh(Socket::address& addr, time_t expires);
+		bool refresh(Socket::address& addr, time_t expires, const char *target_contact);
 		unsigned setTargets(Socket::address& addr);
 		unsigned addTarget(Socket::address& via, time_t expires, const char *contact);
 		unsigned setTarget(Socket::address& via, time_t expires, const char *contact);
